import QtQuick 2.2
import Sailfish.Silica 1.0
import com.jolla.settings 1.0
import org.nemomobile.configuration 1.0

Page {
    id: page

    ConfigurationGroup {
        id: closeIconSettings
        path: "/desktop/lipstick-jolla-home/closeicon"
        property string closeicon_position: "topRight"
        property int closeicon_verticalOffset: Theme.iconSizeMedium/4
        property int closeicon_horizontalOffset: Theme.iconSizeMedium/4
        property bool closeicon_color: false
        property real closeicon_scale: 0.8
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: column.height

        Column {
            id: column
            width: page.width

            PageHeader {
                title: qsTr("General settings")
            }

            Rectangle {
                id: coverPlaceholder
                color: Theme.rgba(Theme.highlightBackgroundColor, Theme.highlightBackgroundOpacity)
                anchors.horizontalCenter: parent.horizontalCenter
                width: Theme.coverSizeLarge.width
                height: Theme.coverSizeLarge.height
                radius: 8

                Image {
                    anchors.fill: parent
                    source: "image://theme/graphic-cover-store-splash"
                }

                Repeater {
                    model: ListModel {
                        ListElement { state: "topRight" }
                        ListElement { state: "topLeft" }
                        ListElement { state: "bottomRight" }
                        ListElement { state: "bottomLeft" }
                        ListElement { state: "top" }
                        ListElement { state: "left" }
                        ListElement { state: "right" }
                        ListElement { state: "bottom" }
                    }

                    delegate: CloseComponent {
                        state: model.state
                        property bool active: closeIconSettings.closeicon_position == model.state
                        opacity: active ? 1.0 : 0.2
                        enabled: true
                        inverted: closeIconSettings.closeicon_color
                        _scale: closeIconSettings.closeicon_scale
                        verticalOffset: active ? closeIconSettings.closeicon_verticalOffset : 0
                        horizontalOffset: active ? closeIconSettings.closeicon_horizontalOffset : 0
                        onClicked: closeIconSettings.closeicon_position = model.state
                    }
                }
            }
            
			TextSwitch {
	            width: parent.width
	            text: qsTr("Use inverted colors")
	            checked: closeIconSettings.closeicon_color
	            onClicked: closeIconSettings.closeicon_color = checked
	        }
            
            Slider {
                width: parent.width
                label: qsTr("Horizontal offset")
                minimumValue: -Theme.iconSizeMedium
                maximumValue: Theme.iconSizeMedium
                stepSize: 1
                value: closeIconSettings.closeicon_horizontalOffset
                valueText: value + " " + qsTr("px.")

                onValueChanged: closeIconSettings.closeicon_horizontalOffset = value
            }

            Slider {
                width: parent.width
                label: qsTr("Vertical offset")
                minimumValue: -Theme.iconSizeMedium
                maximumValue: Theme.iconSizeMedium
                stepSize: 1
                value: closeIconSettings.closeicon_verticalOffset
                valueText: value + " " + qsTr("px.")

                onValueChanged: closeIconSettings.closeicon_verticalOffset = value
            }
            
            Slider {
                width: parent.width
                label: qsTr("Scale")
                minimumValue: 0.6
                maximumValue: 1
                stepSize: 0.1
                value: closeIconSettings.closeicon_scale
                valueText: value

                onValueChanged: closeIconSettings.closeicon_scale = value
            }
            
            PageHeader {
                title: qsTr("About")
            }

            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Created by Ancelad in 0x7E3")
            } 
            
			Item {			    
			    width: 1
				height: Theme.paddingLarge
			}
			
		    Label {
                text: qsTr("Donations are welcome :)")
                width: parent.width
				wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
            }  
            
			Item {			    
			    width: 1
				height: Theme.paddingLarge
			}
            
			Row {
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: Theme.paddingLarge*4
                
                IconButton {
                    icon.source: "paypal.svg"
                    icon.height: Theme.itemSizeMedium
                    icon.width: Theme.itemSizeMedium
                    onClicked: {
                        Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=E33PBZ79WTQJY")
                    }
                }
                
                IconButton {
                    id: sbrf
                    icon.source: "sbrf.svg"
                    icon.height: Theme.itemSizeMedium
                    icon.width: Theme.itemSizeMedium
                }                
			}
 
			Item {			    
			    width: 1
				height: Theme.paddingLarge
			}
 
            Label {
                anchors.horizontalCenter: parent.horizontalCenter
                visible: sbrf.pressed
                text: "4276 1600 2051 7877"
                font.pixelSize: Theme.fontSizeLarge
            }
            
			Item {			    
			    width: 1
				height: Theme.paddingLarge*4
			}            
        }
    }
}
